@@ -226,10 +226,10 @@ class MySQL:
     def get_production_data_from_prod(self, query):
         retry_count = 0
         while retry_count<5:
-            cnx = mysql.connector.connect(user=cred['DE_USER'],
-                                          password=cred['DE_USER_PASSWORD'],
-                                          host=cred['PROD_MYSQL_READER_HOST'],
-                                          port=cred['PORT_2'],
+            cnx = mysql.connector.connect(user=aws.cred['DE_USER'],
+                                          password=aws.cred['DE_USER_PASSWORD'],
+                                          host=aws.cred['PROD_MYSQL_READER_HOST'],
+                                          port=aws.cred['PORT_2'],
                                           database="trellDb")
             try:
                 return pd.read_sql(query + " ;", cnx)
@@ -243,10 +243,10 @@ class MySQL:
     @staticmethod
     def get_rows_array_from_query_prod(self, query):
         try:
-            conn = mysql.connector.connect(user=cred['DE_USER'],
-                                            password=cred['DE_USER_PASSWORD'],
-                                            host=cred['PROD_MYSQL_READER_HOST'],
-                                            port= cred['PORT_2'],
+            conn = mysql.connector.connect(user=aws.cred['DE_USER'],
+                                            password=aws.cred['DE_USER_PASSWORD'],
+                                            host=aws.cred['PROD_MYSQL_READER_HOST'],
+                                            port= aws.cred['PORT_2'],
                                             database='trellDb', charset='utf8mb4')
 
             cursor = conn.cursor()
@@ -259,10 +259,10 @@ class MySQL:
 
     @staticmethod
     def get_analytics_data(self, query, write_to_local=False, fileName="file.csv"):
-        cnx = mysql.connector.connect(user=cred['DATA_USER'],
-                                      password=cred['DATA_PWD'],
-                                      host=cred['ANAL_HOST'],
-                                      port=cred['PORT_2'],
+        cnx = mysql.connector.connect(user=aws.cred['DATA_USER'],
+                                      password=aws.cred['DATA_PWD'],
+                                      host=aws.cred['ANAL_HOST'],
+                                      port=aws.cred['PORT_2'],
                                       database="trellDb")
         try:
             return pd.read_sql(query + " ;", cnx)
@@ -272,10 +272,10 @@ class MySQL:
     @staticmethod
     def get_rows_array_from_query_anal(self, query):
         try:
-            conn = mysql.connector.connect(user=cred['DATA_USER'],
-                                            password=cred['DATA_PWD'],
-                                            host=cred['ANAL_HOST'],
-                                            port=cred['PORT_2'],
+            conn = mysql.connector.connect(user=aws.cred['DATA_USER'],
+                                            password=aws.cred['DATA_PWD'],
+                                            host=aws.cred['ANAL_HOST'],
+                                            port=aws.cred['PORT_2'],
                                             database='trellDb', charset='utf8mb4')
 
             cursor = conn.cursor()
@@ -288,10 +288,10 @@ class MySQL:
 
     @staticmethod
     def get_production_ads_new_data(self, query):
-        conn = mysql.connector.connect(user=cred['ADS_USER'],
-                                       password=cred['ADS_PWD'],
-                                       host=cred['ADS_HOST'],
-                                       port=cred['PORT_2'],
+        conn = mysql.connector.connect(user=aws.cred['ADS_USER'],
+                                       password=aws.cred['ADS_PWD'],
+                                       host=aws.cred['ADS_HOST'],
+                                       port=aws.cred['PORT_2'],
                                        database='ads')
         try:
             return pd.read_sql(query + " ;", conn)
@@ -301,10 +301,10 @@ class MySQL:
     @staticmethod
     def get_rows_array_from_query_prod_ads(self, query):
         try:
-            conn = mysql.connector.connect(user=cred['ADS_USER'],
-                                           password=cred['ADS_PWD'],
-                                           host=cred['ADS_HOST'],
-                                           port=cred['PORT_2'],
+            conn = mysql.connector.connect(user=aws.cred['ADS_USER'],
+                                           password=aws.cred['ADS_PWD'],
+                                           host=aws.cred['ADS_HOST'],
+                                           port=aws.cred['PORT_2'],
                                            database='ads', charset='utf8mb4')
 
             cursor = conn.cursor()
@@ -319,10 +319,10 @@ class MySQL:
     @staticmethod
     def get_rows_array_from_query_magento(self, query):
         try:
-            conn = mysql.connector.connect(user=cred['MAGENTO_USER'],
-                                            password=cred['MAGENTO_PASSWD'],
-                                            host=cred['MAGENTO_HOST'],
-                                            port= cred['MAGENTO_PORT'],
+            conn = mysql.connector.connect(user=aws.cred['MAGENTO_USER'],
+                                            password=aws.cred['MAGENTO_PASSWD'],
+                                            host=aws.cred['MAGENTO_HOST'],
+                                            port= aws.cred['MAGENTO_PORT'],
                                             database='uvmtey5icboxi', charset='utf8mb4')
 
             cursor = conn.cursor()
@@ -337,10 +337,10 @@ class MySQL:
     def get_production_magento(self, query):
 
 
-        conn = mysql.connector.connect(user=cred['MAGENTO_USER'],
-                                        password=cred['MAGENTO_PASSWD'],
-                                        host=cred['MAGENTO_HOST'],
-                                        port= cred['MAGENTO_PORT'],
+        conn = mysql.connector.connect(user=aws.cred['MAGENTO_USER'],
+                                        password=aws.cred['MAGENTO_PASSWD'],
+                                        host=aws.cred['MAGENTO_HOST'],
+                                        port= aws.cred['MAGENTO_PORT'],
                                         database='uvmtey5icboxi', charset='utf8mb4')
         try:
             return pd.read_sql(query + " ;", conn)
@@ -350,13 +350,13 @@ class MySQL:
     @staticmethod
     def get_rows_array_from_query_gratification(self, query):
         try:
-                conn = mysql.connector.connect(user=cred['DATA_USER'],
-                                               password=cred['DATA_PWD'],
-                                               host=cred['GRATIFICATION_HOST'],
-                                               port=cred['PORT_2'],
+                conn = mysql.connector.connect(user=aws.cred['DATA_USER'],
+                                               password=aws.cred['DATA_PWD'],
+                                               host=aws.cred['GRATIFICATION_HOST'],
+                                               port=aws.cred['PORT_2'],
                                                database='gratification', charset='utf8mb4')
 
-                print("host: ", cred['GRATIFICATION_HOST'])
+                print("host: ", aws.cred['GRATIFICATION_HOST'])
                 print("query: ", query)
                 cursor = conn.cursor()
                 cursor.execute(query)
@@ -367,10 +367,10 @@ class MySQL:
                 conn.close()
     @staticmethod
     def get_gratification_data_from_query(self, query):
-        conn = mysql.connector.connect(user=cred['DATA_USER'],
-                                       password=cred['DATA_PWD'],
-                                       host=cred['GRATIFICATION_HOST'],
-                                       port=cred['PORT_2'],
+        conn = mysql.connector.connect(user=aws.cred['DATA_USER'],
+                                       password=aws.cred['DATA_PWD'],
+                                       host=aws.cred['GRATIFICATION_HOST'],
+                                       port=aws.cred['PORT_2'],
                                        database='gratification', charset='utf8mb4')
         try:
             return pd.read_sql(query + " ;", conn)
@@ -380,13 +380,13 @@ class MySQL:
     @staticmethod
     def get_rows_array_from_query_cms(self, query):
         try:
-                conn = mysql.connector.connect(user=cred['CMS_USER'],
-                                               password=cred['CMS_PWD'],
-                                               host=cred['CMS_HOST'],
-                                               port=cred['CMS_PORT'],
+                conn = mysql.connector.connect(user=aws.cred['CMS_USER'],
+                                               password=aws.cred['CMS_PWD'],
+                                               host=aws.cred['CMS_HOST'],
+                                               port=aws.cred['CMS_PORT'],
                                                database='cmsDB', charset='utf8mb4')
 
-                print("host: ", cred['CMS_PORT'])
+                print("host: ", aws.cred['CMS_PORT'])
                 print("query: ", query)
                 cursor = conn.cursor()
                 cursor.execute(query)
@@ -398,10 +398,10 @@ class MySQL:
 
     @staticmethod
     def get_cms_data_from_query(self, query):
-        conn = mysql.connector.connect(user=cred['CMS_USER'],
-                                       password=cred['CMS_PWD'],
-                                       host=cred['CMS_HOST'],
-                                       port=cred['CMS_PORT'],
+        conn = mysql.connector.connect(user=aws.cred['CMS_USER'],
+                                       password=aws.cred['CMS_PWD'],
+                                       host=aws.cred['CMS_HOST'],
+                                       port=aws.cred['CMS_PORT'],
                                        database='cmsDB', charset='utf8mb4')
         try:
             return pd.read_sql(query + " ;", conn)
