@@ -3,8 +3,8 @@ import json
 import boto3
 import logging
 
-from trell_ai_util.utils import LogFormatter
-LogFormatter.apply()
+# from trell_ai_util.utils import LogFormatter
+# LogFormatter.apply()
 
 try:
     secret_name = "data-secret"
@@ -32,4 +32,5 @@ try:
     
 except Exception as err:
     print("* you are not authorized to use Trell pip package *")
-    print("** Either setup AWS CLI or place trell.env in the working directory **")
+    print("** Either setup AWS CLI or use EC2 machine with proper IAM roles attached **")
+    print(err)
